<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage BlogSlog Pro
 * @since BlogSlog Pro 1.0.0
 * @return array An array of default values
 */

function blogslog_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$blogslog_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#fff',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#fe463a',
		'colorscheme'					=> 'default',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,

		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'blogslog-pro' ), '[the-year]', '[site-link]' ),
		'powered_by_text'           	=> esc_html__( 'All Rights Reserved | ', 'blogslog-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'blogslog-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'banner,about,secondary_nav,featured,list_articles,blog,instagram',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'blogslog-pro' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,
		'hide_author'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// Banner
		'banner_section_enable'			=> true,
		'banner_search_enable'			=> true,
		'banner_title'					=> esc_html__( 'We are here to help you with best possible when you find the perfect one for your brand', 'blogslog-pro' ),
		'banner_content_type'			=> 'page',

		// about
		'about_section_enable' 			=> true,
		'about_content_type'			=> 'post',
		'about_title'					=> esc_html__( 'Hello, I&#39;m Sofy Dubinska &#38; I love blogging &#43; travel', 'blogslog-pro' ),
		'about_description'				=> esc_html__( 'There are many examples of organisational systems in nature. From the self-organisation of molecules to form crystals, or entrancing displays of a murmuration of starlings, to the stigmergic communications of ants and the growth of a whole animal from just two starting cells.', 'blogslog-pro' ), 
		'about_btn_title'				=> esc_html__( 'Read More', 'blogslog-pro' ), 

		// Secondary Nav
		'secondary_nav_section_enable' 	=> true,

		// featured
		'featured_section_enable'		=> true,
		'featured_title'				=> esc_html__( 'Featured Posts', 'blogslog-pro' ),
		'featured_btn_title'			=> esc_html__( 'Show More', 'blogslog-pro' ),
		'featured_count'				=> 6,
		'featured_layout'				=> 'featured-modern',
		'featured_content_type'			=> 'category',

		// list_articles
		'list_articles_section_enable' 	=> true,
		'list_articles_content_type'	=> 'category',
		'list_articles_count'			=> 2,
		'list_articles_readmore'		=> esc_html__( 'Continue Reading', 'blogslog-pro' ), 

		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'recent',
		'blog_count'					=> 5,
		'blog_title'					=> esc_html__( 'Popuar Posts', 'blogslog-pro' ),
		'blog_btn_title'				=> esc_html__( 'Show More', 'blogslog-pro' ),

		// instagram
		'instagram_section_enable'		=> true,
		'instagram_count'				=> 6,
		'instagram_title'				=> esc_html__( 'Our Instagram', 'blogslog-pro' ),

	);

	$output = apply_filters( 'blogslog_pro_default_theme_options', $blogslog_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}