<?php
/**
 * Banner section
 *
 * This is the template for the content of banner section
 *
 * @package Theme Palace
 * @subpackage BlogSlog Pro
 * @since BlogSlog Pro 1.0.0
 */
if ( ! function_exists( 'blogslog_pro_add_banner_section' ) ) :
    /**
    * Add banner section
    *
    *@since BlogSlog Pro 1.0.0
    */
    function blogslog_pro_add_banner_section() {
    	$options = blogslog_pro_get_theme_options();
        // Check if banner is enabled on frontpage
        $banner_enable = apply_filters( 'blogslog_pro_section_status', true, 'banner_section_enable' );

        if ( true !== $banner_enable ) {
            return false;
        }
        // Get banner section details
        $section_details = array();
        $section_details = apply_filters( 'blogslog_pro_filter_banner_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render banner section now.
        blogslog_pro_render_banner_section( $section_details );
    }
endif;

if ( ! function_exists( 'blogslog_pro_get_banner_section_details' ) ) :
    /**
    * banner section details.
    *
    * @since BlogSlog Pro 1.0.0
    * @param array $input banner section details.
    */
    function blogslog_pro_get_banner_section_details( $input ) {
        $options = blogslog_pro_get_theme_options();

        // Content type.
        $banner_content_type  = $options['banner_content_type'];
        
        $content = array();
        switch ( $banner_content_type ) {
            case 'page':
                $page_id = ! empty( $options['banner_content_page'] ) ? $options['banner_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['banner_content_post'] ) ? $options['banner_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            case 'custom':
                $custom['title']        = ! empty( $options['banner_title'] ) ? $options['banner_title'] : '';
                $custom['image']        = ! empty( $options['banner_image'] ) ? $options['banner_image'] : '';
                $custom['url']          = ! empty( $options['banner_link'] ) ? $options['banner_link'] : '#';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            default:
            break;
        }

        if ( 'custom' !== $banner_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// banner section content details.
add_filter( 'blogslog_pro_filter_banner_section_details', 'blogslog_pro_get_banner_section_details' );


if ( ! function_exists( 'blogslog_pro_render_banner_section' ) ) :
  /**
   * Start banner section
   *
   * @return string banner content
   * @since BlogSlog Pro 1.0.0
   *
   */
   function blogslog_pro_render_banner_section( $content_details = array() ) {
        $options = blogslog_pro_get_theme_options();
        $banner_content_type  = $options['banner_content_type'];
        $categories = ! empty( $options['banner_categories'] ) ? $options['banner_categories'] : array();

        if ( empty( $content_details ) ) {
            return;
        } 

        foreach ( $content_details as $content ) : ?>

            <div id="featured-introduction-section" class="relative">
                <div class="featured-slider">
                    <article style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                        <div class="overlay"></div>
                        <div class="wrapper">
                            <div class="entry-container">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <?php if ( $options['banner_search_enable'] ) : 
                                    get_search_form(); 
                                endif; ?>

                                <?php if ( ! empty( $categories ) ) : ?>
                                    <span class="cat-links">
                                        <ul class="post-categories"><?php esc_html_e( 'Suggested:', 'blogslog-pro' ); ?>
                                            <?php foreach ( $categories as $category ) : 
                                                $cat_name = get_cat_name( $category );
                                                $cat_url = get_category_link( $category );
                                            ?>
                                                <li><a href="<?php echo esc_url( $cat_url ); ?>"><?php echo esc_html( $cat_name ); ?></a></li>
                                            <?php endforeach; ?>
                                        </ul>
                                    </span><!-- .cat-links -->
                                <?php endif; ?>
                            </div><!-- .entry-container -->
                        </div><!-- .wrapper-->
                    </article>
                </div><!-- .featured-slider -->
            </div><!-- #featured-introduction-section -->

        <?php endforeach;
    }
endif;